The ``falcon.API`` class was renamed to ``falcon.App``. The old ``API`` class
remains available as an alias for backwards-compatibility, but it is now
considered deprecated and will be removed in a future release.
